ContentSharingPickerConfiguration class

Configuration for the system content-sharing picker (macOS 14+).

Use with CaptureStream.setContentSharingPickerConfiguration to control picker behavior for an active stream.

Ref: https://developer.apple.com/documentation/screencapturekit/sccontentsharingpickerconfiguration

Constructors

ContentSharingPickerConfiguration({List<ContentSharingPickerMode>? allowedModes, bool? allowsChangingSelectedContent, List<BundleId>? excludedBundleIds, List<WindowId>? excludedWindowIds})
const

Properties

allowedModes → List<ContentSharingPickerMode>?
Allowed selection modes. When null, all modes are allowed.
final
allowsChangingSelectedContent → bool?
Whether the user can change the selected content for the stream.
final
excludedBundleIds → List<BundleId>?
Bundle IDs to exclude from the picker.
final
excludedWindowIds → List<WindowId>?
Window IDs to exclude from the picker.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited