RunningApplication class

A running application available for capture.

Maps to SCRunningApplication.

Annotations
  • @immutable

Constructors

RunningApplication({required BundleId bundleIdentifier, required String applicationName, required ProcessId processId})
Creates a RunningApplication with the given properties.
const

Properties

applicationName → String
The display name of the application.
final
bundleIdentifier → BundleId
The bundle identifier of the application.
final
hashCode → int
The hash code for this object.
no setteroverride
processId → ProcessId
The process ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override